( cd lib ; rm -rf libnss_nis.so.2 )
( cd lib ; ln -sf libnss_nis-2.7.so libnss_nis.so.2 )
( cd lib ; rm -rf libm.so.6 )
( cd lib ; ln -sf libm-2.7.so libm.so.6 )
( cd lib ; rm -rf libnss_files.so.2 )
( cd lib ; ln -sf libnss_files-2.7.so libnss_files.so.2 )
( cd lib ; rm -rf libresolv.so.2 )
( cd lib ; ln -sf libresolv-2.7.so libresolv.so.2 )
( cd lib ; rm -rf libnsl.so.1 )
( cd lib ; ln -sf libnsl-2.7.so libnsl.so.1 )
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0.4 libbz2.so.1 )
( cd lib ; rm -rf libutil.so.1 )
( cd lib ; ln -sf libutil-2.7.so libutil.so.1 )
( cd lib ; rm -rf libnss_compat.so.2 )
( cd lib ; ln -sf libnss_compat-2.7.so libnss_compat.so.2 )
( cd lib ; rm -rf libcidn.so.1 )
( cd lib ; ln -sf libcidn-2.7.so libcidn.so.1 )
( cd lib ; rm -rf libthread_db.so.1 )
( cd lib ; ln -sf libthread_db-1.0.so libthread_db.so.1 )
( cd lib ; rm -rf libnss_hesiod.so.2 )
( cd lib ; ln -sf libnss_hesiod-2.7.so libnss_hesiod.so.2 )
( cd lib ; rm -rf libanl.so.1 )
( cd lib ; ln -sf libanl-2.7.so libanl.so.1 )
( cd lib ; rm -rf libcrypt.so.1 )
( cd lib ; ln -sf libcrypt-2.7.so libcrypt.so.1 )
( cd lib ; rm -rf libBrokenLocale.so.1 )
( cd lib ; ln -sf libBrokenLocale-2.7.so libBrokenLocale.so.1 )
( cd lib ; rm -rf ld-linux.so.2 )
( cd lib ; ln -sf ld-2.7.so ld-linux.so.2 )
( cd lib ; rm -rf libdl.so.2 )
( cd lib ; ln -sf libdl-2.7.so libdl.so.2 )
( cd lib ; rm -rf libnss_dns.so.2 )
( cd lib ; ln -sf libnss_dns-2.7.so libnss_dns.so.2 )
( cd lib ; rm -rf libpthread.so.0 )
( cd lib ; ln -sf libpthread-2.7.so libpthread.so.0 )
( cd lib ; rm -rf libnss_nisplus.so.2 )
( cd lib ; ln -sf libnss_nisplus-2.7.so libnss_nisplus.so.2 )
( cd lib ; rm -rf libc.so.6 )
( cd lib ; ln -sf libc-2.7.so libc.so.6 )
( cd lib ; rm -rf librt.so.1 )
( cd lib ; ln -sf librt-2.7.so librt.so.1 )
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd usr/lib ; rm -rf libgpg-error.so.0 )
( cd usr/lib ; ln -sf libgpg-error.so.0.4.0 libgpg-error.so.0 )
( cd usr/lib ; rm -rf libexpat.so.1 )
( cd usr/lib ; ln -sf libexpat.so.1.5.2 libexpat.so.1 )
( cd usr/lib ; rm -rf libjpeg.so.62 )
( cd usr/lib ; ln -sf libjpeg.so.62.0.0 libjpeg.so.62 )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.3 libz.so.1 )
( cd usr/lib ; rm -rf libssl.so.0 )
( cd usr/lib ; ln -sf libssl.so.0.9.8 libssl.so.0 )
( cd usr/lib ; rm -rf libgcrypt.so.11 )
( cd usr/lib ; ln -sf libgcrypt.so.11.4.3 libgcrypt.so.11 )
( cd usr/lib ; rm -rf libstdc++.so.5 )
( cd usr/lib ; ln -sf libstdc++.so.5.0.7 libstdc++.so.5 )
( cd usr/lib ; rm -rf libstdc++.so.6 )
( cd usr/lib ; ln -sf libstdc++.so.6.0.9 libstdc++.so.6 )
( cd usr/lib ; rm -rf libgnutls-openssl.so.26 )
( cd usr/lib ; ln -sf libgnutls-openssl.so.26.1.3 libgnutls-openssl.so.26 )
( cd usr/lib ; rm -rf libmysqlclient.so.15 )
( cd usr/lib ; ln -sf libmysqlclient.so.15.0.0 libmysqlclient.so.15 )
( cd usr/lib ; rm -rf libasound.so.2 )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.1.2.25 libpng.so.3 )
( cd usr/lib ; rm -rf libgnutlsxx.so.26 )
( cd usr/lib ; ln -sf libgnutlsxx.so.26.1.3 libgnutlsxx.so.26 )
( cd usr/lib ; rm -rf libgnutls.so.26 )
( cd usr/lib ; ln -sf libgnutls.so.26.1.3 libgnutls.so.26 )
( cd usr/lib ; rm -rf libcrypto.so.0 )
( cd usr/lib ; ln -sf libcrypto.so.0.9.8 libcrypto.so.0 )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.1.2.25 libpng12.so.0 )
( cd usr/lib ; rm -rf libmng.so.1 )
( cd usr/lib ; ln -sf libmng.so.1.0.0 libmng.so.1 )
